@@ -1,11 +1,11 @@
 #' Download the Pediatric Drug Safety database
 #'
-#' Download the database published in Giangreco et al. 2022. Warning, the size of the uncompressed 'sqlite' file is close to 900 MB. Use wit caution
+#' Download the database published in Giangreco et al. 2022. This function will prompt to download the database, so the cache directory will be identified and the database will be downloaded to it only after consent. Warning, the size of the uncompressed 'sqlite' file is close to 0.9GB or 900 MB. Use with caution.
 #'
 #' @param method The method to download the sqlite database. See \code{download.file}
 #' @param quiet Whether to download quietly. See \code{download.file}
 #' @param timeout Extended download session for downloading this file. Default is 1000 seconds.
-#' @param force Whether to force the download of the database. Defaults to FALSE.
+#' @param force Whether to force the download of the database. Defaults to FALSE. Needs to be TRUE for database to download. The function will prompt for confirmation.
 #'
 #'
 #' @return TRUE, invisibly
@@ -16,8 +16,8 @@
 #' @importFrom utils askYesNo
 #'
 #' @examples
-#' if(interactive()){
-#' download_sqlite_db()
+#' if(FALSE){
+#' download_sqlite_db() #set force=TRUE if desired to download 0.9GB file to machine
 #' }
 download_sqlite_db <- function(method="auto",quiet=FALSE,timeout=1e3,force=FALSE) {
 
@@ -30,32 +30,40 @@ download_sqlite_db <- function(method="auto",quiet=FALSE,timeout=1e3,force=FALSE
         options(timeout=newTimeout)
     }
 
-    if(!file.exists(get_db_path()[['destname']]) | force){
+    if(file.exists(get_db_path()[['dest_file']])){
+        message(paste0(
+            "Already exists: ",get_db_path()[['dest_file']]
+        ))
+    }else if(force){
 
-        ans <- utils::askYesNo(paste0("kidsides would like to download a 'sqlite' database to your cache directory at:\n",dirname(get_db_path()[['dest_file']]), ". Is that okay?", sep = "\n"))
+        ans <- utils::askYesNo(
+            paste0("kidsides would like to download a 0.9GB 'sqlite' database to your cache. Is that okay?\nThe file will be located at at: ",
+                   get_db_path()[['kidsides_cache']], sep = "\n")
+        )
         if (!ans) stop("Exiting...", call. = FALSE)
 
+        if(!dir.exists(get_db_path()[['kidsides_cache']])){
+            dir.create(get_db_path()[['kidsides_cache']])
+        }
 
         R.utils::downloadFile(
             url = get_db_path()[['url']],
-            filename = get_db_path()[['dest_file']],
+            filename = get_db_path()[['dest_gzfile']],
             method = method,
             quiet = quiet
         )
         R.utils::gunzip(
+            get_db_path()[['dest_gzfile']],
             get_db_path()[['dest_file']],
-            get_db_path()[['destname']],
             overwrite=T
         )
-    }else if(file.exists(get_db_path()[['dest_file']])){
-        message(paste0(
-            get_db_path()[['dest_file']]," already exists!"
-            ))
     }else{
         message(paste0(
             "Attempt failed to check sqlite exists",
             " or to download from the URL: ",
-            get_db_path()[['url']])
+            get_db_path()[['url']]),"\n",
+            " If you want to download for the first time,",
+            " set argument force=TRUE"
             )
     }
 
@@ -74,13 +82,13 @@ download_sqlite_db <- function(method="auto",quiet=FALSE,timeout=1e3,force=FALSE
 #' @export
 #'
 #' @examples
-#' if(interactive()){
+#' if(FALSE){
 #' download_sqlite_db()
 #' con <- connect_sqlite_db()
 #' disconnect_sqlite_db(con)
 #' }
 connect_sqlite_db <- function(){
-    DBI::dbConnect(RSQLite::SQLite(),dbname=get_db_path()[['destname']])
+    DBI::dbConnect(RSQLite::SQLite(),dbname=get_db_path()[['dest_file']])
 }
 
 #' Disconnect from the Pediatric Drug Safety database
@@ -97,7 +105,7 @@ connect_sqlite_db <- function(){
 #' @export
 #'
 #' @examples
-#' if(interactive()){
+#' if(FALSE){
 #' download_sqlite_db()
 #' con <- connect_sqlite_db()
 #' disconnect_sqlite_db(con)
@@ -108,7 +116,7 @@ disconnect_sqlite_db <- function(con){
 
 #' Return database cache
 #'
-#' This function identifies and returns the cache location for the database on your machine
+#' This function returns the URL, sqlite database file, and cache names to be used for downloading the database to your machine.
 #'
 #' @importFrom tools R_user_dir
 #'
@@ -125,20 +133,23 @@ get_db_path <- function(){
     url <- "https://tlab-kidsides.s3.amazonaws.com/data/effect_peds_19q2_v0.3_20211119.sqlite.gz"
     sqlite_gz_file <- basename(url)
 
-    path <- tools::R_user_dir("kidsides",which = "cache")
+    kidsides_cache <- tools::R_user_dir("kidsides",which = "cache")
 
-    full_path <- paste0(dirname(path),"/",
-                       basename(path))
+    cache <- dirname(kidsides_cache)
 
-    if(!dir.exists(full_path)){
-        dir.create(full_path)
+    if(!dir.exists(cache)){
+        stop(message(paste0("Cache directory doesn't exist.\n",
+                    "Should be located at ",cache)))
     }
 
     lst <- list()
     lst[['url']] <- url
-    lst[['dest_file']] <- paste0(full_path,"/",sqlite_gz_file)
+    lst[['sqlite_gz_file']] <- sqlite_gz_file
     lst[['sqlite_file']] <- strsplit(sqlite_gz_file,"\\.gz")[[1]][1]
-    lst[['destname']] <- paste0(full_path,"/",lst[['sqlite_file']])
+    lst[['cache']] <- cache
+    lst[['kidsides_cache']] <- kidsides_cache
+    lst[['dest_gzfile']] <- paste0(kidsides_cache,"/",sqlite_gz_file)
+    lst[['dest_file']] <- paste0(kidsides_cache,"/",lst[['sqlite_file']])
     lst
 
 }
